# Baroniq
#  to install type
 pip install Baroniq
# to use  it
from baron_class2 import GOD_names
VARNAME=GOD_names()
VARNAME.send_msg(ener token bot here, enter id chat here, enter sec dealy here)
        OR
from baron_class import Baron_bot 
VARNAME=Baron_bot()
VARNAME.send_msg(ener token bot here, enter id chat here, enter sec dealy here)
